@@ -15,6 +15,8 @@ __email__ = 'ajain@lbl.gov'
 __date__ = 'Dec 12, 2012'
 
 
+NEGATIVE_FWID_CTR = 0
+
 def singleton(class_):
     instances = {}
 
@@ -33,7 +35,7 @@ class FWConfig(object):
         self.USER_PACKAGES = ['fireworks.user_objects', 'fireworks.utilities.tests',
                               'fw_tutorials']  # this is where load_object() looks for serialized objects
 
-        self.FW_NAME_UPDATES = {'Transfer Task': 'FileTransferTask', 'Script Task': 'ScriptTask', 'Template Writer Task':'TemplateWriterTask'}  # if you update a _fw_name, you can use this to record the change and maintain
+        self.FW_NAME_UPDATES = {'Transfer Task': 'FileTransferTask', 'Script Task': 'ScriptTask', 'Template Writer Task':'TemplateWriterTask', 'Dupe Finder Exact': 'DupeFinderExact'}  # if you update a _fw_name, you can use this to record the change and maintain
         # deserialization
 
         self.YAML_STYLE = False  # controls whether YAML documents will be nested as braces or blocks (False = blocks)
