@@ -119,7 +119,6 @@ def reset(args):
             raise ValueError('Operation aborted by user.')
     lp.reset(args.password)
 
-
 def add_wf(args):
     lp = get_lp(args)
     if args.dir:
@@ -429,8 +428,7 @@ def lpad():
     init_parser.set_defaults(func=init_yaml)
 
     reset_parser = subparsers.add_parser('reset', help='reset and re-initialize the FireWorks database')
-    #reset_parser.add_argument('--password', help="Today's date,
-    # e.g. 2012-02-25. Password or positive response to input prompt required to protect against accidental reset.")
+    reset_parser.add_argument('--password', help="Today's date,  e.g. 2012-02-25. Password or positive response to input prompt required to protect against accidental reset.")
     reset_parser.set_defaults(func=reset)
 
     addwf_parser = subparsers.add_parser('add', help='insert a Workflow from file')
