@@ -3,9 +3,9 @@
 """
 TODO: add docs
 """
-from fireworks.utilities.fw_serializers import load_object
-from fireworks.utilities.tests.test_serializer import TestSerializer, \
-    ExportTestSerializer
+from fireworks.user_objects.firetasks.unittest_tasks import TestSerializer, ExportTestSerializer
+from fireworks.utilities.fw_serializers import load_object, FWSerializable
+from fireworks.utilities.fw_utilities import explicit_serialize
 
 
 __author__ = "Anubhav Jain"
@@ -20,6 +20,22 @@ import datetime
 import os
 
 
+@explicit_serialize
+class ExplicitTestSerializer(FWSerializable):
+    def __init__(self, a):
+        self.a = a
+
+    def __eq__(self, other):
+        return self.a == other.a
+
+    def to_dict(self):
+        return {"_fw_name": self._fw_name, "a": self.a}
+
+    @classmethod
+    def from_dict(cls, m_dict):
+        return ExplicitTestSerializer(m_dict["a"])
+
+
 class SerializationTest(unittest.TestCase):
     def setUp(self):
         test_date = datetime.datetime.utcnow()
@@ -104,5 +120,13 @@ class SerializationTest(unittest.TestCase):
                          'Implicit import fails!')
 
 
+class ExplicitSerializationTest(unittest.TestCase):
+    def setUp(self):
+        self.s_obj = ExplicitTestSerializer(1)
+        self.s_dict = self.s_obj.to_dict()
+
+    def test_explicit_serialization(self):
+        self.assertEqual(load_object(self.s_dict), self.s_obj)
+
 if __name__ == "__main__":
     unittest.main()
\ No newline at end of file
